#/bin/bash

[[ -r /etc/os-release ]] && . /etc/os-release || exit_status

[[ "$1" != "nocolor" ]] && source colors

function exit_status()
{
  echo "Script failure"
  exit 1
}

function help()
{
  echo "Help Func"
  exit 0
}

function info_hw()
{
  local CPU_VENDOR=$(cat /proc/cpuinfo |grep "model name" |head -n1 |cut -d : -f2)
  local CPU_CORES=$(cat /proc/cpuinfo |egrep -ic "^processor")
  local TOT_MEM=$(cat /proc/meminfo |grep MemTotal |cut -d : -f2 | awk '{print $1"/1024"}' |bc -l |cut -d "." -f 1)
  local FREE_MEM=$(cat /proc/meminfo |grep MemFree |cut -d : -f2 | awk '{print $1"/1024"}' |bc -l |cut -d "." -f 1)
  local USED_MEM=$(echo $TOT_MEM - $FREE_MEM | bc)
  local HDD_SIZE=$(fdisk -l /dev/sda | grep Disk | cut -d : -f2  | awk '{print $1" "$2}' | head -n1)
  local HDD_VENDOR=$(lshw -class disk |grep vendor |head -n1)
  local VIDEO_CARD=$(lshw -class Video |grep -E "description" | cut -d: -f2)
  local ACT_NETINT=$(/sbin/ip -o link show |awk '{print $2,$9}' |grep "UP" |sed 's/://g' | awk '{print $1}' |head -n1)
  local NIC_UUID=$(cat /sys/class/net/$ACT_NETINT/address|sed 's/://g' | awk '{print $1}' |head -n1)
  local INET_ADDR=$(/sbin/ifconfig eth0 | grep 'inet ' | awk '{ print $2}')
  local BIOS=$(/usr/bin/sudo dmidecode -t 0 |grep "Vendor" | cut -d : -f2)
  local BIOS_VER=$(/usr/bin/sudo dmidecode -t 0 |grep "Version" | cut -d : -f2)
  local MB_VER=$(/usr/bin/sudo dmidecode -t 2 | grep "Product Name" | cut -d : -f2)

  echo
  echo "Hardware RIG info"
  echo "${BYELLOW}CPU info           :${NOCOLOR}"${CYAN}$CPU_VENDOR${NOCOLOR} "${BYELLOW}Cores:${NOCOLOR}" ${CYAN}$CPU_CORES${NOCOLOR}
  echo "${BYELLOW}Motherboard version:${NOCOLOR}"${CYAN}$MB_VER${NOCOLOR}
  echo "${BYELLOW}Motherboard BIOS   :${NOCOLOR}"${CYAN} $BIOS ${NOCOLOR} \
  ","${CYAN} $BIOS_VER ${NOCOLOR}"${BYELLOW}version.${NOCOLOR}"
  echo "${BYELLOW}Total memory       :${NOCOLOR}"${CYAN} $TOT_MEM "{$BYELLOW}Mb. Free:${NOCOLOR}"${CYAN} $FREE_MEM "${BYELLOW}Mb. Used:${NOCOLOR}"${CYAN} $USED_MEM${NOCOLOR}"${BYELLOW}Mb.${NOCOLOR}"
  echo "${BYELLOW}Hard drive         :${NOCOLOR}"${CYAN} $HDD_VENDOR ${NOCOLOR}"${BYELLOW}HDD Size:${NOCOLOR}"${CYAN} $HDD_SIZE ${NOCOLOR}"${BYELLOW}HDD usage:${NOCOLOR}"
  echo "${BYELLOW}Video cards        :${NOCOLOR}"${CYAN} $VIDEO_CARD ${NOCOLOR}
  echo "${BYELLOW}Network adapters   :${NOCOLOR}"${CYAN} $ACT_NETINT ${NOCOLOR}"${BYELLOW}MAC:${NOCOLOR}"${CYAN} $NIC_UUID ${NOCOLOR}"${BYELLOW}Addr:${NOCOLOR}"${CYAN} $INET_ADDR ${NOCOLOR}
  echo
  lshw
  echo
  echo "PCI information"
  /usr/bin/lspci
  echo
  echo "USB Information"
  /usr/bin/lsusb
  echo
}

function rig_info()
{
  local CONFIG="/hive-config/rig.conf"
  local RIG_ID=$(cat $CONFIG | grep RIG_ID | cut -d = -f2)
  local WORKER_NAME=$(cat $CONFIG | grep WORKER_NAME | cut -d = -f2)
  local FARM_ID=$(cat $CONFIG | grep FARM_ID | cut -d = -f2)
  local WATCHDOG=$(cat $CONFIG | grep WD_ENABLED | cut -d = -f2)
  local HIVEOS_VERSION=$(cat /etc/os-release | grep VERSION_ID | cut -d = -f2)
  local KERNEL=$(uname -a | awk {'print $3'})
  local ARCH=$(uname -m)

  echo
  echo "${BYELLOW}HIVEOS VERSION:${NOCOLOR}"${CYAN} $HIVEOS_VERSION ${NOCOLOR}
  echo "${BYELLOW}KERNEL VERSION:${NOCOLOR}"${CYAN} $KERNEL ${NOCOLOR}
  echo "${BYELLOW}ARCH          :${NOCOLOR}"${CYAN} $ARCH ${NOCOLOR}

  echo "${BYELLOW}RIG ID        :${NOCOLOR}"${CYAN} $RIG_ID ${NOCOLOR}
  echo "${BYELLOW}WORKER NAME   :${NOCOLOR}"${CYAN} $WORKER_NAME ${NOCOLOR}
  echo "${BYELLOW}FARM ID       :${NOCOLOR}"${BYELLOW} $FARM_ID ${NOCOLOR}
  if [ ! $WATCHDOG ]; then
    echo "WD_ENABLED" $WATCHDOG
  else
    echo "WD_DISABLED" $WATCHDOG
  fi
  echo
}

function load_avg_status()
{
  local pid_array=$(ls /proc | grep -E '^[0-9]+$')
  local clock_ticks=$(getconf CLK_TCK)
  local total_memory=$(grep -Po '(?<=MemTotal:\s{8})(\d+)' /proc/meminfo)
  local CPU_USAGE=$(top -bn1 | sed -n '/Cpu/p' | cut -d : -f2)
  echo "CPU USAGE"
  echo $CPU_USAGE
  echo "Processes usage"

}

function sys_logs()
{
  echo
  echo "Hive system log"
  cat /var/log/syslog
  echo
  echo "Hive dmesg log"
  dmesg --color -H -T --ctime
  echo
}
while :
do
  case $@ in
    -h | --help)
      help
    break
    ;;
    -i | --info-hw)
      info_hw
    break
    ;;
    -r | --riginfo)
      rig_info
    break
    ;;
    -l | --loadavgstatus)
      load_avg_status
    break
    ;;
    -s | --syslogs)
      sys_logs
    break;
    ;;
    -a | --all)
      rig_info
      info_hw
      load_avg_status
      sys_logs
    break
    ;;
    --)
      shift
    break
    ;;
    -*)
      exit 1
    ;;
    *)
      break
    ;;
  esac
done

exit 0

